@@ -2,6 +2,8 @@ from socketio import Client
 
 
 class CustomSocketIO(Client):
+    """A custom socketio client."""
+
     def __init__(self, address: str = None, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.address = address
@@ -36,3 +38,9 @@ class CustomSocketIO(Client):
 
     def isConnected(self):
         return not self.connected
+
+    def toogle(self, value: bool):
+        if value:
+            self.start()
+        else:
+            self.stop()
